@@ -26,7 +26,7 @@ import (
 	"os"
 	"path/filepath"
 
-	"github.com/pkg/errors"
+	"github.com/k1LoW/errors"
 	"github.com/spf13/cobra"
 )
 
@@ -51,7 +51,7 @@ tbls completion fish ~/.config/fish/completions/tbls.fish
 	ValidArgs: []string{"bash", "zsh", "fish", "powershell"},
 	Args: func(cmd *cobra.Command, args []string) error {
 		if len(args) != 1 {
-			return errors.Errorf("accepts 1 arg, received %d", len(args))
+			return fmt.Errorf("accepts 1 arg, received %d", len(args))
 		}
 		if err := cobra.OnlyValidArgs(cmd, args); err != nil {
 			return err
