@@ -132,20 +132,27 @@ func TestMergeAditionalData(t *testing.T) {
 	if err != nil {
 		t.Error(err)
 	}
-	err = c.LoadConfigFile(filepath.Join(testdataDir(), "config_test_tbls.yml"))
-	if err != nil {
+	if err := c.LoadConfigFile(filepath.Join(testdataDir(), "config_test_tbls.yml")); err != nil {
 		t.Error(err)
 	}
-	err = c.MergeAdditionalData(&s)
-	if err != nil {
+	if err := c.MergeAdditionalData(&s); err != nil {
 		t.Error(err)
 	}
 	if want := 1; len(s.Relations) != want {
 		t.Errorf("got %v\nwant %v", len(s.Relations), want)
 	}
-	users, _ := s.FindTableByName("users")
-	posts, _ := s.FindTableByName("posts")
-	title, _ := posts.FindColumnByName("title")
+	users, err := s.FindTableByName("users")
+	if err != nil {
+		t.Fatal(err)
+	}
+	posts, err := s.FindTableByName("posts")
+	if err != nil {
+		t.Fatal(err)
+	}
+	title, err := posts.FindColumnByName("title")
+	if err != nil {
+		t.Fatal(err)
+	}
 	if want := "post title"; title.Comment != want {
 		t.Errorf("got %v\nwant %v", title.Comment, want)
 	}
@@ -247,15 +254,29 @@ func TestModifySchema(t *testing.T) {
 		t.Error(err)
 	}
 	tests := []struct {
-		name      string
-		desc      string
-		labels    []string
-		comments  []AdditionalComment
-		relations []AdditionalRelation
-		wantRel   int
+		name             string
+		desc             string
+		labels           []string
+		comments         []AdditionalComment
+		relations        []AdditionalRelation
+		viewpointATables []string
+		viewpointBTables []string
+		wantRel          int
 	}{
-		{"", "", []string{}, nil, nil, 3},
-		{"mod_name_and_desc", "this is test schema", []string{}, nil, nil, 3},
+		{"", "", []string{}, nil, nil, []string{
+			"users",
+			"posts",
+		}, []string{
+			"users",
+			"user_options",
+		}, 3},
+		{"mod_name_and_desc", "this is test schema", []string{}, nil, nil, []string{
+			"users",
+			"posts",
+		}, []string{
+			"users",
+			"user_options",
+		}, 3},
 		{"relations", "", []string{}, nil, []AdditionalRelation{
 			{
 				Table:         "users",
@@ -263,6 +284,12 @@ func TestModifySchema(t *testing.T) {
 				Columns:       []string{"id"},
 				ParentColumns: []string{"id"},
 			},
+		}, []string{
+			"users",
+			"posts",
+		}, []string{
+			"users",
+			"user_options",
 		}, 4},
 		{"not_override", "", []string{}, nil, []AdditionalRelation{
 			{
@@ -273,6 +300,12 @@ func TestModifySchema(t *testing.T) {
 				Def:           "Additional Relation",
 				Override:      false,
 			},
+		}, []string{
+			"users",
+			"posts",
+		}, []string{
+			"users",
+			"user_options",
 		}, 4},
 		{"override", "", []string{}, nil, []AdditionalRelation{
 			{
@@ -285,6 +318,12 @@ func TestModifySchema(t *testing.T) {
 				Def:               "Override Relation",
 				Override:          true,
 			},
+		}, []string{
+			"users",
+			"posts",
+		}, []string{
+			"users",
+			"user_options",
 		}, 3},
 	}
 	for _, tt := range tests {
@@ -294,11 +333,21 @@ func TestModifySchema(t *testing.T) {
 			c.Labels = tt.labels
 			c.Comments = tt.comments
 			c.Relations = tt.relations
+			c.Viewpoints = append(c.Viewpoints, Viewpoint{
+				Name:   "A",
+				Desc:   "Viewpoint A",
+				Tables: tt.viewpointATables,
+			})
+			c.Viewpoints = append(c.Viewpoints, Viewpoint{
+				Name:   "B",
+				Desc:   "Viewpoint B",
+				Tables: tt.viewpointBTables,
+			})
+
 			s := newTestSchemaViaJSON(t)
 			if err := c.ModifySchema(s); err != nil {
 				t.Error(err)
 			}
-
 			got, err := json.MarshalIndent(s, "", "  ")
 			if err != nil {
 				t.Error(err)
