@@ -6,8 +6,8 @@ import (
 	"strings"
 
 	"cloud.google.com/go/spanner"
+	"github.com/k1LoW/errors"
 	"github.com/k1LoW/tbls/schema"
-	"github.com/pkg/errors"
 	"google.golang.org/api/iterator"
 )
 
