@@ -21,10 +21,10 @@
 package main
 
 import (
-	_ "github.com/denisenkom/go-mssqldb"
 	_ "github.com/go-sql-driver/mysql"
 	_ "github.com/lib/pq"
 	_ "github.com/mattn/go-sqlite3"
+	_ "github.com/microsoft/go-mssqldb"
 	_ "github.com/snowflakedb/gosnowflake"
 
 	"github.com/k1LoW/tbls/cmd"
