@@ -7,16 +7,17 @@ import (
 	"io"
 	"os"
 	"path/filepath"
+	"sort"
 	"strconv"
 	"strings"
 	"text/template"
 
+	"github.com/k1LoW/errors"
 	"github.com/k1LoW/tbls/config"
 	"github.com/k1LoW/tbls/output"
 	"github.com/k1LoW/tbls/output/mermaid"
 	"github.com/k1LoW/tbls/schema"
 	"github.com/mattn/go-runewidth"
-	"github.com/pkg/errors"
 	"github.com/pmezard/go-difflib/difflib"
 	"github.com/samber/lo"
 	"gitlab.com/golang-commonmark/mdurl"
@@ -521,11 +522,15 @@ func (m *Md) makeSchemaTemplateData(s *schema.Schema) map[string]interface{} {
 	// Viewpoints
 	viewpointsData := m.viewpointsData(s.Viewpoints, number, adjust, showOnlyFirstParagraph)
 
+	// Enums
+	enumData := m.enumData(s.Enums)
+
 	return map[string]interface{}{
 		"Schema":     s,
 		"Tables":     tablesData,
 		"Functions":  functionsData,
 		"Viewpoints": viewpointsData,
+		"Enums":      enumData,
 	}
 }
 
@@ -873,6 +878,35 @@ func (m *Md) functionsData(functions []*schema.Function, number, adjust, showOnl
 	return data
 }
 
+func (m *Md) enumData(enums []*schema.Enum) [][]string {
+	data := [][]string{}
+
+	if len(enums) == 0 {
+		return data
+	}
+
+	header := []string{
+		m.config.MergedDict.Lookup("Name"),
+		m.config.MergedDict.Lookup("Values"),
+	}
+	headerLine := []string{"----", "-------"}
+	data = append(data,
+		header,
+		headerLine,
+	)
+
+	for _, e := range enums {
+		sort.Strings(e.Values)
+		d := []string{
+			e.Name,
+			strings.Join(e.Values, ", "),
+		}
+		data = append(data, d)
+	}
+
+	return data
+}
+
 func (m *Md) viewpointsData(viewpoints []*schema.Viewpoint, number, adjust, showOnlyFirstParagraph bool) [][]string {
 	data := [][]string{}
 	header := []string{
